/**
 * @function datasource
 */

'use strict';

var fs = require('fs');
var path = require('path');
var extend = require('extend');
var arrayfilter = require('arrayfilter');
var sortProperties = require('fmtjson/lib/sort_properties');
var defineLocale = require('./define_locale');

/** @lends datasource */
function datasource(dirname, buildin) {
  var result = {};

  fs.readdirSync(dirname).filter(arrayfilter.patternReject(/^index\./)).filter(arrayfilter.patternReject(/^\./)).filter(arrayfilter.patternReject(/^_/)).map(function (filename) {
    return path.resolve(dirname, filename);
  }).forEach(function (filename) {
    var lang = path.basename(filename, path.extname(filename));
    var src = sortProperties(extend(true, {}, buildin && buildin[lang], require(filename), {
      $lang: lang
    }));
    result[lang] = defineLocale(src);
  });
  return result;
}

module.exports = datasource;